@@ -82,9 +82,10 @@ class Tester:
     async def _compile(self, code, blacklist_dirs: List[str], language: str, tmpdir: str, timeout: int, memory: int,
                        encoding: str, max_proc: int):
         filename = os.path.join(tmpdir, 'code')
-        file = open(filename, 'wb')
-        file.write(code.encode(encoding))
-        file.close()
+
+        with open(filename, 'wb') as file:
+            file.write(code.encode(encoding))
+
         cmds = COMPILE_COMMANDS[language](filename)
         compilation_time = 0
         compiler_message = ''
